@@ -13,6 +13,20 @@
 @CREATED    : March 10, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincreshape.c,v $
+ * Revision 6.14  2008/01/17 02:33:02  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.13  2008/01/13 09:38:54  stever
+ * Avoid compiler warnings about functions and variables that are defined
+ * but not used.  Remove some such functions and variables,
+ * conditionalize some, and move static declarations out of header files
+ * into C files.
+ *
+ * Revision 6.12  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
  * Revision 6.11  2005/08/26 21:07:18  bert
  * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
  *
@@ -97,10 +111,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincreshape/mincreshape.c,v 6.11 2005/08/26 21:07:18 bert Exp $";
-#endif
-
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -117,6 +127,35 @@ static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincreshape/mincreshap
 #include <time_stamp.h>
 #include "mincreshape.h"
 
+
+static void get_arginfo(int argc, char *argv[],
+                        Reshape_info *reshape_info);
+static int get_fillvalue(char *dst, char *key, char *nextArg);
+static int get_dimsize(char *dst, char *key, char *nextArg);
+static int get_axis_order(char *dst, char *key, char *nextArg);
+static int get_axis_range(char *dst, char *key, char *nextArg);
+static int get_arg_vector(char *dst, char *key, char *nextArg);
+static void get_default_datatype(int mincid, nc_type *datatype, int *is_signed,
+                                 double valid_range[2]);
+static void setup_dim_sizes(int icvid, int mincid, Dimsize_list *dimsize_list);
+static void setup_reshaping_info(int icvid, int mincid,
+                                 int do_norm, double fillvalue, int do_scalar,
+                                 char *axis_order[], Axis_ranges *axis_ranges,
+                                 long hs_start[], long hs_count[],
+                                 int max_chunk_size_in_kb,
+                                 Reshape_info *reshape_info);
+static void setup_output_file(int mincid, char *history,
+                              Reshape_info *reshape_info);
+static void create_dim_var(int outmincid, int outdimid,
+                           int inicvid, int cur_image_dim, int inmincid,
+                           long input_start, long input_count);
+static void copy_dimension_values(int outmincid, int outdimid, int inmincid,
+                                  long input_start, long input_count);
+static void copy_dim_var_values(int outmincid, char *dimname, char *varname,
+                                int inmincid,
+                                long input_start, long input_count);
+
+
 /* Main program */
 
 int main(int argc, char *argv[])
